summaryrefslogtreecommitdiffstats
path: root/iso/kiso.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-03 02:49:54 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-03 02:49:54 +0000
commit6ffad5a006df848f5e9a80ca31e5faec8ed65e62 (patch)
tree3757770dc3586efff30fdfe30f7e36b64ab883f1 /iso/kiso.h
parent1359f43e963c10d08c6c78f4806da291ca216bfe (diff)
downloadkrusader-6ffad5a006df848f5e9a80ca31e5faec8ed65e62.tar.gz
krusader-6ffad5a006df848f5e9a80ca31e5faec8ed65e62.zip
TQt4 port krusader
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/krusader@1239136 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'iso/kiso.h')
-rw-r--r--iso/kiso.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/iso/kiso.h b/iso/kiso.h
index ceddb4a..546b09a 100644
--- a/iso/kiso.h
+++ b/iso/kiso.h
@@ -25,10 +25,10 @@
#include <sys/stat.h>
#include <sys/types.h>
-#include <qdatetime.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qdict.h>
+#include <tqdatetime.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqdict.h>
#include "kisofile.h"
#include "kisodirectory.h"
@@ -50,15 +50,15 @@ public:
* Do not use application/x-tgz or so. Only the compression layer !
* If the mimetype is ommitted, it will be determined from the filename.
*/
- KIso( const QString& filename, const QString & mimetype = QString::null );
+ KIso( const TQString& filename, const TQString & mimetype = TQString() );
/**
* Creates an instance that operates on the given device.
- * The device can be compressed (KFilterDev) or not (QFile, etc.).
- * WARNING: don't assume that giving a QFile here will decompress the file,
+ * The device can be compressed (KFilterDev) or not (TQFile, etc.).
+ * WARNING: don't assume that giving a TQFile here will decompress the file,
* in case it's compressed!
*/
- KIso( QIODevice * dev );
+ KIso( TQIODevice * dev );
/**
* If the .iso is still opened, then it will be
@@ -68,12 +68,12 @@ public:
/**
* The name of the os file, as passed to the constructor
* Null if you used the QIODevice constructor.
*/
- QString fileName() { return m_filename; }
+ TQString fileName() { return m_filename; }
- bool writeDir( const QString& , const QString& , const QString& );
- bool prepareWriting( const QString& , const QString& , const QString& , uint );
+ bool writeDir( const TQString& , const TQString& , const TQString& );
+ bool prepareWriting( const TQString& , const TQString& , const TQString& , uint );
bool doneWriting( uint );
void setStartSec(int startsec) { m_startsec = startsec; }
@@ -98,10 +98,10 @@ private:
* @internal
*/
void addBoot(struct el_torito_boot_descriptor* bootdesc);
- void prepareDevice( const QString & filename, const QString & mimetype, bool forced = false );
+ void prepareDevice( const TQString & filename, const TQString & mimetype, bool forced = false );
int m_startsec;
- QString m_filename;
+ TQString m_filename;
protected:
virtual void virtual_hook( int id, void* data );
private:
@@ -68,12 +68,12 @@ public:
/**
* The name of the os file, as passed to the constructor
- * Null if you used the QIODevice constructor.
+ * Null if you used the TQIODevice constructor.
*/